@@ -24,7 +24,9 @@
   * doing it manually. */
 inline QString toQString(const std::string& str)
 {
-	return QString(str);
+//	return QString(str);
+//	return QString(str.c_str());
+	return QString::fromStdString(str);
 }
 
 inline QString& toQString(QString& str)
@@ -34,10 +36,11 @@ inline QString& toQString(QString& str)
 
 inline std::string toString(const QString& str)
 {
-	return str.operator std::string();
+//	return str.operator std::string();
+	return std::string(str.toAscii());
 }
 
-/** Avoid accidental conversions like toString(str) where str already is a std::string*/
+/** Avoid accidental conversions like toString(str) where str already is a std::string */
 inline std::string& toString(std::string& str)
 {
 	return str;
