@@ -3,11 +3,6 @@
 namespace NPlugin
 {
 
-vector< pair<QString, QAction*> > PluginContainer::actions()
-{
-	return vector< pair<QString, QAction*> >();
-}
-
 QWidget* PluginContainer::getSettingsWidget(QWidget* pParent)
 {
 	return 0;
@@ -18,8 +13,9 @@ void PluginContainer::applySettings()
 	return;
 }
 
-void PluginContainer::loadSettings(const QDomElement source)
+QDomElement PluginContainer::loadSettings(const QDomElement source)
 {
+	return source;
 }
 
 void PluginContainer::saveSettings(NXml::XmlData& outData, QDomElement parent) const
