@@ -17,6 +17,7 @@
 
 // plugins offered
 #include "aptsearchplugin.h"
+#include "aptactionplugin.h"
 #include "packagestatusplugin.h"
 #include "packagedescriptionplugin.h"
 #include "installedversionplugin.h"
@@ -45,7 +46,11 @@ Plugin* AptPluginFactory::createPlugin(const string& name) const
 {
 	if (name=="AptSearchPlugin")
 	{
-		return new AptSearchPlugin(_pAptSearch);// 
+		return new AptSearchPlugin(_pAptSearch, _pPackageDB); 
+	}
+	if (name=="AptActionPlugin")
+	{
+		return new AptActionPlugin();
 	}
 	if (name=="PackageStatusPlugin")
 	{
