@@ -18,6 +18,9 @@
 
 namespace NPlugin {
 
+const QString InstalledVersionPlugin::PLUGIN_NAME = "InstalledVersionPlugin";
+
+
 InstalledVersionPlugin::InstalledVersionPlugin(NApt::IPackageDB* pPackageDB) :
 	_title(tr("Installed Version Plugin")),
 	_briefDescription(tr("Shows the version of the installed package in the package list")),
@@ -44,11 +47,15 @@ void InstalledVersionPlugin::init(IProvider* pProvider)
 // ShortInformationPlugin Interface
 /////////////////////////////////////////////////////
 
-const QString InstalledVersionPlugin::shortInformationText(int packageID)
+const QString InstalledVersionPlugin::shortInformationText(const string& package)
 {
 	try 
 	{
-		return QString(_pPackageDB->getPackageRecord(packageID).installedVersion);
+		const NApt::IPackage& packageStruct(_pPackageDB->getPackageRecord(package));
+		if (packageStruct.installedState() == NApt::Package::INSTALLED)
+			return QString(packageStruct.installedVersion());
+		else
+			return packageStruct.installedVersion();
 	}
 	catch (const PackageNotFoundException& e)
 	{
