@@ -1,36 +1,54 @@
 #include <sstream>
 #include <iostream>
 
-#include <qlistbox.h>
-#include <qpoint.h>
-#include <qpopupmenu.h>
-#include <qlayout.h>
-#include <qmessagebox.h>
 #include <qcheckbox.h>
+#include <qlayout.h>
 #include <qlabel.h>
+#include <q3listbox.h>
+#include <QMainWindow>
+#include <qmessagebox.h>
+#include <qpoint.h>
+#include <q3popupmenu.h>
+#include <QVBoxLayout>
+
+// Tagcoll
+#if 0
+#include <tagcoll/Expression.h>
+#include <tagcoll/Filter.h>
+#include <tagcoll/Exception.h>
+#endif
+#include <ept/cache/debtags/tagmap.h>
 
-#include <ExpressionFilter.h>
-#include <FilterChain.h>
-#include <TagcollBuilder.h>
-#include <Exception.h>
 
 #include <helpers.h>
 #include <exception.h>
 
+// NPlugin
+#include <packagenotfoundexception.h>
 
 #include "debtagsplugin.h"
 
-#include "stringtagcollbuilder.h"
+// NPlugin
 #include "iprovider.h"
 
+// NUtil
+#include "debtagshelper.h"
+
+
 #include "selectioninputanddisplay.h"
 #include "tagselectionwidget.h"
 #include "choosentagsdisplay.h"
 
 
+typedef ept::configuration::apt::cache::Package Package;
+
+
 namespace NPlugin
 {
 
+const QString DebtagsPlugin::PLUGIN_NAME = "DebtagsPlugin";
+
+
 /////////////////////////////////////////////////////
 // Constructors/ Destructors
 /////////////////////////////////////////////////////
@@ -40,7 +58,6 @@ DebtagsPlugin::DebtagsPlugin(const DebtagsPluginContainer& container) :
 { 
 	_pChooserWidget = 0;
 	_pTagsDisplay = 0;
-	_pHandleMaker = 0;
 	_pProvider = 0;
 	_pIncludeSelection = 0;
 	_pExcludeSelection = 0;
@@ -63,16 +80,15 @@ void DebtagsPlugin::init(IProvider* pProvider)
 {
 	QMainWindow* pWindow = pProvider->mainWindow();
 	_pProvider = pProvider;
-	_pHandleMaker = &pProvider->handleMaker();
 
 	_pChooserWidget = new TagChooserWidget(pWindow, "TagChooserWidget");
 	_pTagsDisplay = new ChoosenTagsDisplay(pWindow, "ChoosenTagsDisplay");
 	
 	// this will be garbage collected if the parent _pChooserWidget will be deleted
 	NWidgets::TagSelectionWidget* pIncludeSelectionWidget = 
-		new NWidgets::TagSelectionWidget(_pChooserWidget, "IncludeSelection");
+		new NWidgets::TagSelectionWidget(_pChooserWidget, &_container, "IncludeSelection");
 	NWidgets::TagSelectionWidget* pExcludeSelectionWidget = 
-		new NWidgets::TagSelectionWidget(_pChooserWidget, "ExcludeSelection");
+		new NWidgets::TagSelectionWidget(_pChooserWidget, &_container, "ExcludeSelection");
 	
 	_pTagsDisplay->show();
 	// currently disabled as the exclude tag option is not too useful and wastes some space
@@ -111,7 +127,6 @@ void DebtagsPlugin::init(IProvider* pProvider)
 	);
 	
 
-	_pIncludeSelection->tagSelectionListView()->setColl(_container.collection());
 	showExcludeWidgets(false);	// hide the exclude selection part by default
 	connect(_pChooserWidget->_pExcludeTagsCheck, SIGNAL(toggled(bool)), this, SLOT(showExcludeWidgets(bool)));
 	
@@ -136,16 +151,16 @@ QString DebtagsPlugin::description() const
 		"It also offers searching by tags that can be selected from a list."); 
 }
 
-//
+/////////////////////////////////////////////////////
 // Search Plugin Interface 
-//
+/////////////////////////////////////////////////////
 
 QWidget* DebtagsPlugin::shortInputAndFeedbackWidget() const
 {
 	return _pTagsDisplay;
 }
 
-const Tagcoll::OpSet<int>& DebtagsPlugin::searchResult() const
+const std::set<string>& DebtagsPlugin::searchResult() const
 { 
 	return _searchResult; 
 };
@@ -156,17 +171,20 @@ void DebtagsPlugin::clearSearch()
 	_pExcludeSelection->tagSelectionListView()->deselectAll();
 }
 
-//
+/////////////////////////////////////////////////////
 // Information Plugin Interface 
-//
+/////////////////////////////////////////////////////
 
-QString DebtagsPlugin::informationText(int packageID)
+QString DebtagsPlugin::informationText(const string& package)
 {
 	{	// add the tags of the package to the description
-		Tagcoll::OpSet<string> tagset = _container.collection()->getTagsetForItem(packageID);
+		Package packageEntity= NUtil::getPackageByName(package);
+		if (!packageEntity.valid())
+			throw NPlugin::PackageNotFoundException(package);
+		std::set<string> tagset = NUtil::tagsToStrings(_container.collection()->getTagsOfItem(packageEntity));
 		if (tagset.empty()) return _emptyString;
 		QString detailsString = "<b>Tags:</b> ";
-		for (Tagcoll::OpSet<string>::iterator it = tagset.begin(); ; )
+		for (std::set<string>::iterator it = tagset.begin(); ; )
 		{
 			detailsString += toQString( *it );
 			if ( ++it == tagset.end() )
@@ -199,10 +217,10 @@ std::string DebtagsPlugin::createSearchExpression()
 {
 	ostringstream oexpr;
 	// the list view that displays the selected tags
-	QListBox* pTagsView = _pTagsDisplay->_pIncludeTagsView;
+	Q3ListBox* pTagsView = _pTagsDisplay->_pIncludeTagsView;
 	for (uint i = 0; i < pTagsView->count(); ++i)
 	{
-		oexpr << pTagsView->text(i);
+		oexpr << toString(pTagsView->text(i));
 		// if we do not have the last item or we have tags to exclude
 		if ( i+1< pTagsView->count() || _pTagsDisplay->_pExcludeTagsView->count()!=0)	
 			oexpr << " && ";
@@ -211,7 +229,7 @@ std::string DebtagsPlugin::createSearchExpression()
 	pTagsView = _pTagsDisplay->_pExcludeTagsView;
 	for (uint i = 0; i < pTagsView->count(); ++i)
 	{
-		oexpr << "!" << pTagsView->text(i);
+		oexpr << "!" << toString(pTagsView->text(i));
 		if ( i+1<pTagsView->count())	// if we do not have the last item 
 			oexpr << " && ";
 	}
@@ -232,35 +250,8 @@ void DebtagsPlugin::evaluateSearch()
 	else
 	{
 		_isInactive = false;
-		if (_pTagsDisplay->_pExcludeTagsView->count()!=0)	// if we want to exclude some tags
-		{
-			// send the package collection through the filter into the result
-			// and than copy the result to the _searchResult
-			Tagcoll::FilterChain<int, string> filters;
-			#warning this must be fixed!!
-			#warning this must be fixed!!
-			#warning this must be fixed!!
-			/// @todo fix the Expression Filter (hopefully Enrico will make it a template)
-/*			Tagcoll::ExpressionFilter filter;
-			if ( !filter.setExpression(expression) )	// no error should occur!
-				cerr << "Programmers error please report to bensmail@gmx.net: Error in tag expression "
-					<< endl;
-			filters.appendFilter(&filter);
-			Tagcoll::TagCollection result;
-			filters.setConsumer(&result);
-			_container.collection()->output(filters);
-			_searchResult = result.getAllItems();*/
-		}
-		else	// do not use TagcollFilter
-		{
-			QListBox* pIncludeTagsView = _pTagsDisplay->_pIncludeTagsView;
-			Tagcoll::OpSet<string> ts;
-			for (uint i = 0; i < pIncludeTagsView->count(); ++i)
-			{
-				ts.insert( toString(pIncludeTagsView->text(i)) );
-			}
-			_searchResult = _container.collection()->getCompanionItems(ts);
-		}
+		_searchResult = NUtil::packagesToStrings( _container.collection()->getItemsHavingTags(
+			_pIncludeSelection->tagSelectionListView()->getSelectedTags()) );
 	}
 	_pProvider->reportReady(this);
 	emit searchChanged(this);
@@ -279,7 +270,6 @@ void DebtagsPlugin::debtagsDataChanged()
 		setWidgetsEnabled(true);
 	}
 //	clearSearch();
-	_pIncludeSelection->tagSelectionListView()->setColl(_container.collection());
 }
 
 void DebtagsPlugin::setWidgetsEnabled(bool enabled)
@@ -292,3 +282,7 @@ void DebtagsPlugin::setWidgetsEnabled(bool enabled)
 
 }	// namespace NPlugin
 
+#undef emit
+#include <ept/cache/apt/packages.tcc>
+#include <ept/cache/debtags/vocabulary.tcc>
+#include <ept/cache/tag.tcc>
