@@ -1,26 +1,41 @@
-#include <qlineedit.h>
+#include <cassert>
+
 #include <qcombobox.h>
+#include <qlineedit.h>
+#include <QMainWindow>
 #include <qtimer.h>
 #include <qspinbox.h>
 #include <qstatusbar.h>
 #include <qpushbutton.h>
 
+#include <tagcoll/utils/set.h>
+#include <ept/cache/debtags/tagmap.h>
+
+// NUtil
 #include <helpers.h>
+
+// NPlugin
 #include <iprovider.h>
 
+// NPlugin
 #include "relatedplugin.h"
 #include "relatedinput.h"
 #include "relatedfeedbackwidget.h"
 
+// NUtil
+#include "debtagshelper.h"
+
 namespace NPlugin
 {
 
+const QString RelatedPlugin::PLUGIN_NAME = "RelatedPlugin";
+
+
 RelatedPlugin::RelatedPlugin(const DebtagsPluginContainer& container)
 	: _container(container)
 {
 	_pMainWindow = 0;
 	_pProvider = 0;
-	_pHandleMaker = 0;
 	_pRelatedInput = 0;
 	_pRelatedFeedbackWidget = 0;
 	_isInactive = true;
@@ -59,7 +74,6 @@ void RelatedPlugin::init(IProvider* pProvider)
 {
 	_pProvider = pProvider;
 	_pMainWindow = pProvider->mainWindow();
-	_pHandleMaker = &_pProvider->handleMaker();
 	
 	_pRelatedInput = new RelatedInput(_pMainWindow, "RelatedInput");
 	const set<string>& packages = pProvider->packages();
@@ -71,6 +85,10 @@ void RelatedPlugin::init(IProvider* pProvider)
 	connect(_pRelatedInput->_pClearButton, SIGNAL(clicked()), SLOT(onClearSearch()));
 	
 	_pRelatedFeedbackWidget = new RelatedFeedbackWidget(_pMainWindow, "RelatedFeedbackWidget");
+	_pRelatedFeedbackWidget->setClearButton(
+		pProvider->createClearButton(_pRelatedFeedbackWidget, "AptClearButton"), 0);
+	connect(_pRelatedFeedbackWidget->_pClearButton, SIGNAL(clicked()), SLOT(onClearSearch()));
+
 	_pRelatedFeedbackWidget->setShown(false);
 	connect(
 		_pRelatedInput->_pMaximumDistanceInput, SIGNAL(valueChanged(int)), 
@@ -108,11 +126,40 @@ void RelatedPlugin::clearSearch()
 	_pRelatedInput->_pPackageInput->setCurrentText("");
 }
 
-const Tagcoll::OpSet<int>& RelatedPlugin::searchResult() const
+const std::set<string>& RelatedPlugin::searchResult() const
 {
 	return _searchResult;
 }
 
+/////////////////////////////////////////////////////
+// ScorePlugin Interface
+/////////////////////////////////////////////////////
+	
+bool RelatedPlugin::offersScore() const 
+{
+	if (isInactive())
+		return false;
+ 	string package = toString(_pRelatedInput->_pPackageInput->currentText());
+	return !_container.collection()->getTagsOfItem(NUtil::getPackageByName(package)).empty();
+}
+
+map<string, float> RelatedPlugin::getScore(const set<string>& packages) const
+{
+	// the map that will be returned
+	map<string, float> result;
+	assert(!isInactive());
+ 	string package = toString(_pRelatedInput->_pPackageInput->currentText());
+	int maxdist = _pRelatedInput->_pMaximumDistanceInput->value();
+	std::set<Tag> ts = _container.collection()->getTagsOfItem(NUtil::getPackageByName(package));
+	for (set<string>::const_iterator it = packages.begin(); it != packages.end(); ++it)
+	{
+		int dist = tagcoll::utils::set_distance(ts,  _container.collection()->getTagsOfItem(NUtil::getPackageByName(*it)));
+		result[*it] = float(maxdist - dist + 1) / (maxdist+1);
+	}
+	return result;
+}
+
+
 /////////////////////////////////////////////////////
 // helper functions
 /////////////////////////////////////////////////////
@@ -125,45 +172,24 @@ void RelatedPlugin::onInputTextChanged(const QString& text)
 
 void RelatedPlugin::evaluateSearch()
 {
-	// stop the delay timer in case that this evaluateSearch() was triggered by
-	// another event
 	_pProvider->reportBusy(this, tr("Searching Package Database for related packages"));
 	_searchResult.clear();
 	_pRelatedFeedbackWidget->_pRelatedSearchTextView->setText(
 		_pRelatedInput->_pPackageInput->currentText()
 	);
  	string package = toString(_pRelatedInput->_pPackageInput->currentText());
-	int packageID = _pHandleMaker->getHandle(package);
 	_isInactive = package.empty();	// if no input was given the search is inactive
 	if ( !_isInactive )
 	{
-		///@todo check here if has item is neccesary
-/*		if ( !_pPackageCollection->hasItem(packageID) )	// if the package entered is not in the collection
-		{
-			_isInactive = true;
-			_pProvider->reportError(
-				tr("No such package"),
-				tr("There is no package with the given name available.")
-			);
-		}
-		else */
 		{
 			int maxdist = _pRelatedInput->_pMaximumDistanceInput->value();
-			Tagcoll::OpSet<string> ts = _container.collection()->getTagsetForItem( packageID );
-			// the result holds all the items with the
-			_searchResult = _container.collection()->getItemsForTagset(ts);	
-				// same tagset as the currently selected package
-			if (maxdist!=0)
+			
+			Package packageEntity = NUtil::getPackageByName(package);
+			std::set<Tag> tags = _container.collection()->getTagsOfItem(packageEntity);
+			std::set<Package> result = _container.collection()->getRelatedItems(tags, maxdist);
+			for (std::set<Package>::const_iterator it = result.begin(); it != result.end(); ++it)
 			{
-				// Get the related tagsets
-				list< Tagcoll::OpSet<string> > rel = 
-					_container.collection()->getRelatedTagsets(ts, maxdist);
-				// add the packages which have tags like the related packages
-				for (list< Tagcoll::OpSet<string> >::const_iterator i = rel.begin();
-						i != rel.end(); i++)
-				{
-					_searchResult += _container.collection()->getItemsForTagset(*i);
-				}
+				_searchResult.insert(it->name());
 			}
 		}
 	}
@@ -189,3 +215,6 @@ void RelatedPlugin::setWidgetsEnabled(bool enabled)
 }
  
 }	// namespace NPlugin
+
+#undef emit
+#include <ept/cache/debtags/tagmap.tcc>
