@@ -20,6 +20,12 @@
 
 class QLineEdit;
 
+namespace NPlugin
+{
+	class DebtagsPluginContainer;
+}
+
+
 namespace NWidgets {
 
 /**
@@ -36,7 +42,7 @@ private slots:
 	void onFilterTextChanged(const QString& text)	
 		{ _pTagSelectionList->setFilterByNamePattern( toString(text) ); };
 public:
-	TagSelectionWidget(QWidget *parent = 0, const char *name = 0);
+	TagSelectionWidget(QWidget *parent, const NPlugin::DebtagsPluginContainer* pContainer, const char *name = 0);
 	~TagSelectionWidget();
 	TagSelectionListView* tagSelection()	{ return _pTagSelectionList; };
 };
