@@ -11,7 +11,7 @@
 //
 #include "progressdisplaydlg.h"
 
-#include <qprogressbar.h>
+#include <q3progressbar.h>
 #include <qapplication.h>
 #include <qlabel.h>
 
@@ -20,8 +20,11 @@
 namespace NUtil {
 
 ProgressDisplayDlg::ProgressDisplayDlg(QWidget *parent, const char *name, bool modal)
- : PluginProgressDlg(parent, name, modal), IProgressObserver()
+ : QDialog(parent), IProgressObserver()
 {
+	setObjectName(name);
+	setModal(modal);
+	setupUi(this);
 }
 
 
