@@ -12,7 +12,7 @@
 #ifndef __NUTILPROGRESSDISPLAYDLG_H_2005_03_20
 #define __NUTILPROGRESSDISPLAYDLG_H_2005_03_20
 
-#include ".ui/pluginprogressdlg.h"
+#include <.ui/ui_pluginprogressdlg.h>
 
 #include "iprogressobserver.h"
 
@@ -22,7 +22,7 @@ namespace NUtil
 /**
 @author Benjamin Mesing
 */
-class ProgressDisplayDlg : public PluginProgressDlg, public IProgressObserver
+class ProgressDisplayDlg : public QDialog, public Ui::PluginProgressDlg, public IProgressObserver
 {
 Q_OBJECT
 public:
