@@ -14,6 +14,8 @@
 
 #include <list>
 
+#include <QStringList>
+
 #include "extalgorithm.h"
 #include "runcommand.h"
 
@@ -30,17 +32,27 @@ namespace NApplication
   */
 class RunCommandInXterm : public RunCommand
 {
-	list<QString> _arguments;
+	Q_OBJECT
+	QStringList _arguments;
 	/** The process currently executed. Is 0 if no process is currently executed.  */
 	QProcess* _pProcess;
 private slots:
 	void onProcessExited();
+protected:
+	/** @brief This is a helper function implementing start() and startAsRoot() 
+	  *
+	  * It does the thing described in either start() or startAsRoot().
+	  * @param root if to start the command as root
+	  * @see start(), startAsRoot()
+	  */
+	bool start(bool root);
 public:
 	RunCommandInXterm();
 	~RunCommandInXterm();
 	virtual void addArgument(const QString& arg);
 	virtual bool start();
-	/** This returns allways true as I do not see a way to get hold of the exit status using an xterm. */
+	virtual bool startAsRoot();
+	/** @brief This returns always true as I do not see a way to get hold of the exit status using an xterm. */
 	virtual bool processExitedSuccessful() const	{ return true; };
 };
 
